use cgmath::{Deg, InnerSpace, Point2};
use galactica_content as content;
use galactica_render::{AnchoredUiPosition, UiSprite};
use galactica_world::{util, ShipPhysicsHandle, World};

pub fn build_radar(
	player: &ShipPhysicsHandle,
	physics: &World,
	ct: &content::Content,
) -> Vec<UiSprite> {
	let mut out = Vec::new();

	let radar_range = 2000.0;
	let radar_size = 300.0;

	out.push(UiSprite {
		texture: ct.get_texture_handle("ui::radar"),
		pos: AnchoredUiPosition::NorthWest(Point2 { x: 10.0, y: -10.0 }),
		dimensions: Point2 {
			x: radar_size,
			y: radar_size,
		},
		angle: Deg(0.0),
	});

	let (_, pr) = physics.get_ship_body(player).unwrap();
	let pr = util::rigidbody_position(pr);
	for (s, r) in physics.iter_ship_body() {
		if s.physics_handle == *player {
			continue;
		}
		let r = util::rigidbody_position(r);
		let d = r - pr;
		let m = d.magnitude() / radar_range;
		if m < 0.8 {
			out.push(UiSprite {
				texture: ct.get_texture_handle("ui::blip"),
				pos: AnchoredUiPosition::NorthWest(
					Point2 {
						x: radar_size / 2.0 + 10.0,
						y: radar_size / -2.0 - 10.0,
					} + (d / radar_range * 150.0),
				),
				dimensions: Point2 { x: 1.0, y: 1.0 } * 5.0f32.min((0.8 - m) * 50.0),
				angle: Deg(0.0),
			});
		}
	}

	return out;
}
